import logging

from mmc.plugins.packages.config import PackagesConfig
from mmc.plugins.packages.manager import UpdatesManager


logger = logging.getLogger(__name__)
VERSION = "0.6.2"
APIVERSION = "0:0:0"
REVISION = ""

def getVersion(): return VERSION
def getApiVersion(): return APIVERSION
def getRevision(): return REVISION

def activate():
    config = PackagesConfig("packages")
    if config.disabled:
        logger.warning("Plugin packages: disabled by configuration.")
        return False

    if not UpdatesManager().has_active_backend:
        return False
    else:
        UpdatesManager().check()

    try:
        from mmc.plugins.dashboard.manager import DashboardManager
        from mmc.plugins.packages.panel import UpdatesPanel
        DM = DashboardManager()
        DM.register_panel(UpdatesPanel("updates"))
    except ImportError:
        pass

    return True


# Exported methods
def list_updates(filter=""):
    return UpdatesManager().list(filter)

def check_updates():
    return UpdatesManager().check()

def run_updates():
    return UpdatesManager().run()

def updates_status():
    return UpdatesManager().status
