import os
import imp
import glob
import logging

from mmc.support.mmctools import SingletonN
from mmc.plugins.packages.config import PackagesConfig

logger = logging.getLogger(__name__)


class UpdatesManager(object):
    __metaclass__ = SingletonN

    def __init__(self):
        self.config = PackagesConfig("packages")
        self.backends_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'backend')
        self.backend = False
        self.backend_methods = ['list', 'check', 'run', 'status']

        for backend in glob.glob("%s/[a-z]*.py" % self.backends_path):
            backend_name = os.path.splitext(os.path.basename(backend))[0]
            f, p, d = imp.find_module(backend_name, [self.backends_path])
            backend_module = imp.load_module(backend_name, f, p, d)
            backend_class = getattr(backend_module, "%sBackend" % backend_name.capitalize(), None)
            if backend_class:
                backend_inst = backend_class(self.config.updates_refresh, self.config.need_reboot)
                if backend_inst.is_available():
                    self.backend = backend_inst
                    logger.info("Using backend %s" % self.backend)
                    break

    @property
    def has_active_backend(self):
        if self.backend:
            return True
        return False

    def __getattr__(self, name):
        if not self.has_active_backend:
            raise Exception("No package backend available.")
        # Delegate some methods to the backend
        if name in self.backend_methods:
            return getattr(self.backend, name)
        else:
            return self.__getattr__(name)
